# Copyright (C) 2017 McAfee, Inc. All rights reserved.
# Cookbook Name:: Cloud-Workload-Security
# Recipe:: Deploy the McAfee Agent & Endpoint Security ( Windows /Linux)

# Ruby standard libraries
require 'openssl'
require 'open-uri'
require 'rexml/document'
require 'socket'
require 'net/http'
require 'json'


Chef::Log.info "Recipe running on #{node[:platform]} platform"
#Verify attributes and value existence. If not give runtime error
# unless attributes_check
#   Chef::Log.fatal('Required attributes not present')
#   raise
# end

#SECTION 1: Get the required values for forming McAfee Agent url for downloading & installation.
gpid=""
cloud_accountid=""
entity_id=""
@arr_api_response=""
#Get group id & account id
#Get the region of the instance after figuring whether instance running is on Azure or AWS.
aws_check_url="http://169.254.169.254/latest/meta-data/services/partition"
aws_instance_id="http://169.254.169.254/latest/meta-data/instance-id"
azure_check_url="http://169.254.169.254/metadata/instance/compute/location?api-version=2017-03-01&format=text"
azure_instance_id="http://169.254.169.254/metadata/instance/compute/resourceId?api-version=2017-03-01&format=text"
response=getMetadataRequest(aws_check_url)
if (response.code=="200")
	vendor=response.body[0..2]
	if (vendor=="aws")
		Chef::Log.info "AWS Machine"
		response=getMetadataRequest(aws_instance_id)
		if response.code=="200"
			entity_id=response.body
		end
	end
elsif(response.code == "404")
	response = getMetadataRequest(azure_check_url)
	if(response.code == "200")
		vendor = "azure"
		Chef::Log.info "Azure Machine"
		response=getMetadataRequest(azure_instance_id)
		if response.code=="200"
			entity_id=response.body
		end
	else
		Chef::Log.fatal('Not able to get the region of the instance. Exiting the run.')
		raise
	end
end

ma_url=getMAInstallUrlFromServer(entity_id)


#SECTION 2: INSTALL MCAFEE AGENT
file_name = ""
if node[:platform] == "windows"
  file_name = "McAfeeAgent.exe"
else
  file_name = "McAfeeSmartInstall.sh"
end

		File.open("/#{file_name}", "wb") do |saved_file|
			open(ma_url, "rb",
			:ssl_verify_mode => OpenSSL::SSL::VERIFY_NONE) do |read_file|
				saved_file.write(read_file.read)
			end
		end
		if File.size?("/#{file_name}").nil?
			Chef::Log.info "#{file_name} didn't download properly. Retrying."
			sleep(60)
		end
	# rescue Timeout::Error, Errno::EINVAL, Errno::ECONNRESET, EOFError, Net::HTTPBadResponse, Net::HTTPHeaderSyntaxError, Net::ProtocolError => e
	# 	Chef::Log.fatal "FATAL: Error executing Remote Command to download the McAfee Agent.\n #{e.message} \n Do an Exit !!"
	# 	return e.message



if File.size?("/#{file_name}").nil?
	Chef::Log.error "Failed to download #{file_name}. Exiting the execution."
	raise
else
	Chef::Log.info "McAfee Agent downloaded successfully"
end

# Install the agent
Chef::Log.info "Installing McAfee Agent"
if node[:platform] == "windows" 
	package 'McAfee Agent Win' do
	  source "/#{file_name}"
	  installer_type :custom
	end
else
  ruby_block 'McAfee Agent' do
    block do
      system "chmod u+x /#{file_name}"
      system "/./#{file_name}"
    end
  end
end
Chef::Log.info "McAfee Agent installed successfully"